@@ -21,13 +21,26 @@ import re
 from functools import partial
 import threading
 import serial
-from serial.tools import list_ports
+from serial.tools import list_ports, list_ports_common
 from serial import FIVEBITS, SIXBITS, SEVENBITS, EIGHTBITS
 from serial import PARITY_NONE, PARITY_EVEN, PARITY_ODD, PARITY_MARK, PARITY_SPACE
 from serial import STOPBITS_ONE, STOPBITS_ONE_POINT_FIVE, STOPBITS_TWO
 import io
 import time
 import logging
+import os
+
+
+def list_serial_ports():
+    """List available serial ports, including a workaround for Raspberry Pi
+    
+    The built-in list of com ports misses the RPi hardware serial port.
+    This workaround explicitly checks for it, and includes it if present.
+    """
+    comports = list_ports.comports()
+    if os.path.exists("/dev/ttyS0"):
+        comports.append(list_ports_common.ListPortInfo("/dev/ttyS0"))
+    return comports
 
 
 class ExtensibleSerialInstrument(object):
@@ -344,7 +357,7 @@ class ExtensibleSerialInstrument(object):
         with self.communications_lock:
             success = False
             # Loop through serial ports, apparently 256 is the limit?!
-            for port_name, _, _ in list_ports.comports():
+            for port_name, _, _ in list_serial_ports():
                 try:
                     logging.info("Trying port {}".format(port_name))
                     self.open(port_name)
